name             "chef_handler"
maintainer       "Opscode, Inc."
maintainer_email "cookbooks@opscode.com"
license          "Apache 2.0"
description      "Distribute and enable Chef Exception and Report handlers"
long_description IO.read(File.join(File.dirname(__FILE__), 'README.md'))
version          "1.1.4"
