#
# Author:: Paul Morotn (<pmorton@biaprotect.com>)
# Cookbook Name:: windows
# Provider:: auto_run
#
# Copyright:: 2011, Business Intelligence Associates, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

action :create do
  windows_registry 'HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Run' do
    values new_resource.name => "\"#{new_resource.program}\" #{new_resource.args}"
  end
end

action :remove do 
  windows_registry 'HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Run' do
    values new_resource.name => ''
    action :remove
  end
end