#
# Generated by Chef for <%= node['hostname'] %>
#
# Local modifications will be overwritten.
#
# The MySQL database server configuration file.
#
# You can copy this to one of:
# - "/etc/mysql/my.cnf" to set global options,
# - "~/.my.cnf" to set user-specific options.
#
# One can use all long options that the program supports.
# Run program with --help to get a list of available options and with
# --print-defaults to see which it would actually understand and use.
#
# For explanations see
# http://dev.mysql.com/doc/mysql/en/server-system-variables.html

# This will be passed to all mysql clients
# It has been reported that passwords should be enclosed with ticks/quotes
# escpecially if they contain "#" chars...
# Remember to edit /etc/mysql/debian.cnf when changing the socket location.
[client]
port            = <%= node['mysql']['port'] %>
socket          = <%= node['mysql']['socket'] %>

# Here is entries for some specific programs
# The following values assume you have at least 32M ram

# This was formally known as [safe_mysqld]. Both versions are currently parsed.
[mysqld_safe]
socket          = <%= node['mysql']['socket'] %>
nice            = <%= node['mysql']['nice'] %>

[mysqld]
#
# * Basic Settings
#

#
# * IMPORTANT
#   If you make changes to these settings and your system uses apparmor, you may
#   also need to also adjust /etc/apparmor.d/usr.sbin.mysqld.
#

user            = mysql
pid-file        = <%= node['mysql']['pid_file'] %>
socket          = <%= node['mysql']['socket'] %>
port            = <%= node['mysql']['port'] %>
basedir         = <%= node['mysql']['basedir'] %>
datadir         = <%= node['mysql']['data_dir'] %>
tmpdir          = <%= node['mysql']['tmpdir'].join(':') %>
skip-external-locking
<%- if node['mysql']['tunable']['skip-name-resolve'] %>
skip-name-resolve
<%- end %>

# Charset and Collation
character-set-server = <%= node['mysql']['tunable']['character-set-server'] %>
collation-server     = <%= node['mysql']['tunable']['collation-server'] %>
<%- if node['mysql']['tunable']['lower_case_table_names'] %>
lower_case_table_names = <%= node['mysql']['tunable']['lower_case_table_names'] %>
<%- end %>
<%- if node['mysql']['tunable']['event_scheduler'] %>
event_scheduler      = <%= node['mysql']['tunable']['event_scheduler'] %>
<%- end %>
<%- if node['mysql']['tunable']['skip-character-set-client-handshake'] %>
skip-character-set-client-handshake
<%- end %>
<%- if (node['mysql']['tunable']['lc_messages_dir'] && node['mysql']['tunable']['lc_messages']) %>
lc_messages_dir	    = <%= node['mysql']['lc_messages_dir'] %>
lc_messages	    = <%= node['mysql']['lc_messages'] %>
<%- elsif (node['mysql']['tunable']['languages']) %>
languages	    = <%= node['mysql']['tunable']['languages'] %>
<%- end %>

#
# Instead of skip-networking the default is now to listen only on
# localhost which is more compatible and is not less secure.
bind-address            = <%= node['mysql']['bind_address'] %>
#
# * Fine Tuning
#
key_buffer_size         = <%= node['mysql']['tunable']['key_buffer_size'] %>
max_allowed_packet      = <%= node['mysql']['tunable']['max_allowed_packet'] %>
thread_stack            = <%= node['mysql']['tunable']['thread_stack'] %>
thread_cache_size       = <%= node['mysql']['tunable']['thread_cache_size'] %>
sort_buffer_size        = <%= node['mysql']['tunable']['sort_buffer_size'] %>
read_buffer_size        = <%= node['mysql']['tunable']['read_buffer_size'] %>
read_rnd_buffer_size    = <%= node['mysql']['tunable']['read_rnd_buffer_size'] %>
join_buffer_size        = <%= node['mysql']['tunable']['join_buffer_size'] %>

auto-increment-increment = <%= node['mysql']['auto-increment-increment'] %>
auto-increment-offset    = <%= node['mysql']['auto-increment-offset'] %>

# This replaces the startup script and checks MyISAM tables if needed
# the first time they are touched
myisam-recover          = <%= node['mysql']['tunable']['myisam-recover'] %>
max_connections         = <%= node['mysql']['tunable']['max_connections'] %>
max_connect_errors      = <%= node['mysql']['tunable']['max_connect_errors'] %>
concurrent_insert       = <%= node['mysql']['tunable']['concurrent_insert'] %>
connect_timeout         = <%= node['mysql']['tunable']['connect_timeout'] %>
wait_timeout            = <%= node['mysql']['tunable']['wait_timeout'] %>
net_read_timeout        = <%= node['mysql']['tunable']['net_read_timeout'] %>
net_write_timeout       = <%= node['mysql']['tunable']['net_write_timeout'] %>
back_log                = <%= node['mysql']['tunable']['back_log'] %>
table_cache             = <%= node['mysql']['tunable']['table_cache'] %>
<%- if node['mysql']['tunable']['table_open_cache'] %>
table_open_cache        = <%= node['mysql']['tunable']['table_open_cache'] %>
<%- end %>
tmp_table_size          = <%= node['mysql']['tunable']['tmp_table_size'] %>
max_heap_table_size     = <%= node['mysql']['tunable']['max_heap_table_size'] %>
bulk_insert_buffer_size = <%= node['mysql']['tunable']['bulk_insert_buffer_size'] %>
open-files-limit        = <%= node['mysql']['tunable']['open-files-limit'] %>

# Default Table Settings
<%- if node['mysql']['tunable']['sql_mode'] %>
sql_mode                = "<%= node['mysql']['tunable']['sql_mode'] %>"
<%- end %>

#
# * Query Cache Configuration
#
query_cache_limit       = <%= node['mysql']['tunable']['query_cache_limit'] %>
query_cache_size        = <%= node['mysql']['tunable']['query_cache_size'] %>
#
# * Logging
#
# Both location gets rotated by the cronjob.
# Be aware that this log type is a performance killer.
#log            = /var/log/mysql/mysql.log
#
# Error logging goes to syslog. This is a Debian improvement :)
<%- if node['mysql']['tunable']['log_error'] %>
log_error = <%= node['mysql']['tunable']['log_error'] %>
<%- end %>
<%- if node['mysql']['tunable']['log_warnings'] %>
log_warnings
<%- end %>
#
# * Replication
#


#
# Here you can see queries with especially long duration
<%- if node['mysql']['version'].to_f >= 5.5 %>
slow_query_log          = <%= node['mysql']['tunable']['slow_query_log'] %>
<% else %>
log_slow_queries        = <%= node['mysql']['tunable']['slow_query_log'] %>
<% end %>

long_query_time         = <%= node['mysql']['tunable']['long_query_time'] %>
<%- if node['mysql']['tunable']['log_queries_not_using_index'] and node['mysql']['slow_query_log']  %>
log-queries-not-using-indexes
<%- end %>
#
# The following can be used as easy to replay backup logs or for replication.
# note: if you are setting up a replication slave, see README.Debian about
#       other settings you may need to change.
<%- if node['mysql']['tunable']['server_id'] %>
server-id = <%= node['mysql']['tunable']['server_id'] %>
<% end %>
<%- if node['mysql']['tunable']['log_bin'] %>
log_bin 		= <%= node['mysql']['tunable']['log_bin'] %>
binlog_format           = <%= node['mysql']['tunable']['binlog_format'] %>
log_slave_updates       = <%= node['mysql']['tunable']['log_slave_updates'] %>
<%- end %>
<%- if node['mysql']['tunable']['log_bin_trust_function_creators'] %>
log_bin_trust_function_creators
<%- end %>
expire_logs_days        = <%= node['mysql']['tunable']['expire_logs_days'] %>
max_binlog_size         = <%= node['mysql']['tunable']['max_binlog_size'] %>
binlog_cache_size       = <%= node['mysql']['tunable']['binlog_cache_size'] %>
#binlog_do_db           = include_database_name
#binlog_ignore_db       = include_database_name
<%- if node['mysql']['tunable']['relay_log'] %>
relay_log               = <%= node['mysql']['tunable']['relay_log'] %>
<%- end %>
<%- if node['mysql']['tunable']['relay_log_index'] %>
relay_log_index         = <%= node['mysql']['tunable']['relay_log_index'] %>
<%- end %>

sync_binlog             = <%= node['mysql']['tunable']['sync_binlog'] %>
<%- if node['mysql']['tunable']['skip_slave_start'] %>
skip_slave_start
<%- end %>
<%- if node['mysql']['tunable']['read_only'] %>
read_only = 1
<%- end %>

<%- if node['mysql']['tunable']['transaction-isolation'] %>
transaction-isolation = <%= node['mysql']['tunable']['transaction-isolation'] %>
<%- end %>

<%- if node['mysql']['tunable']['slave_compressed_protocol'] %>
slave_compressed_protocol = <%= node['mysql']['tunable']['slave_compressed_protocol'] %>
<%- end %>
#
# * InnoDB
#
# InnoDB is enabled by default with a 10MB datafile in /var/lib/mysql/.
# Read the manual for more InnoDB related options. There are many!
# You might want to disable InnoDB to shrink the mysqld process by circa 100MB.
#skip-innodb

<%- if node["mysql"]["version"].to_f >= 5.5 %>
innodb_write_io_threads         = <%= node['mysql']['tunable']['innodb_write_io_threads'] %>
innodb_io_capacity              = <%= node['mysql']['tunable']['innodb_io_capacity'] %>
innodb_read_io_threads          = <%= node['mysql']['tunable']['innodb_read_io_threads'] %>
innodb_buffer_pool_instances    = <%= node['mysql']['tunable']['innodb_buffer_pool_instances'] %>
<%- end %>

## InnoDB Plugin Independent Settings
innodb_data_home_dir            = <%= node['mysql']['data_dir']  %>
innodb_log_group_home_dir       = <%= node['mysql']['log_dir']  %>
<%- if node['mysql']['log_files_in_group'] %>
innodb_log_files_in_group       = <%= node['mysql']['log_files_in_group'] %>
<%- end %>

<%- if node['mysql']['innodb_status_file'] %>
innodb_status_file
<%- end %>
<%- if node['mysql']['tunable']['innodb_file_per_table'] %>
innodb_file_per_table
<%- end %>
innodb_table_locks              = <%= node['mysql']['tunable']['innodb_table_locks'] %>
innodb_lock_wait_timeout        = <%= node['mysql']['tunable']['innodb_lock_wait_timeout'] %>
innodb_thread_concurrency       = <%= node['mysql']['tunable']['innodb_thread_concurrency'] %>
innodb_commit_concurrency       = <%= node['mysql']['tunable']['innodb_commit_concurrency'] %>
innodb_support_xa               = <%= node['mysql']['tunable']['innodb_support_xa'] %>
<%- if node['mysql']['tunable']['skip-innodb-doublewrite'] %>
skip-innodb-doublewrite
<%- end %>

innodb_buffer_pool_size = <%= node['mysql']['tunable']['innodb_buffer_pool_size'] %>
innodb_log_file_size    = <%= node['mysql']['tunable']['innodb_log_file_size'] %>
innodb_additional_mem_pool_size = <%= node['mysql']['tunable']['innodb_additional_mem_pool_size'] %>
innodb_data_file_path   = <%= node['mysql']['tunable']['innodb_data_file_path'] %>
innodb_flush_log_at_trx_commit = <%= node['mysql']['tunable']['innodb_flush_log_at_trx_commit'] %>
<%- if node['mysql']['tunable']['innodb_flush_method'] %>
innodb_flush_method     = <%= node['mysql']['tunable']['innodb_flush_method'] %>
<%- end %>
innodb_log_buffer_size  = <%= node['mysql']['tunable']['innodb_log_buffer_size'] %>
<%- if node['mysql']['tunable']['innodb_adaptive_flushing'] %>
innodb_adaptive_flushing  = <%= node['mysql']['tunable']['innodb_adaptive_flushing'] %>
<%- end %>

<% if @skip_federated %>
#
# * Federated
#
# The FEDERATED storage engine is disabled since 5.0.67 by default in the .cnf files
# shipped with MySQL distributions (my-huge.cnf, my-medium.cnf, and so forth).
#
skip-federated
<% end %>
#
# * Security Features
#
# Read the manual, too, if you want chroot!
# chroot = /var/lib/mysql/
#
# For generating SSL certificates I recommend the OpenSSL GUI "tinyca".
#
# ssl-ca=/etc/mysql/cacert.pem
# ssl-cert=/etc/mysql/server-cert.pem
# ssl-key=/etc/mysql/server-key.pem

[mysqldump]
quick
quote-names
max_allowed_packet      = <%= node['mysql']['tunable']['max_allowed_packet'] %>

[mysql]
#no-auto-rehash # faster start of mysql but no tab completition

[myisamchk]
key_buffer                = <%= node['mysql']['tunable']['max_allowed_packet'] %>

myisam_sort_buffer_size   = <%= node['mysql']['tunable']['myisam_sort_buffer_size'] %>
myisam_max_sort_file_size = <%= node['mysql']['tunable']['myisam_max_sort_file_size'] %>
myisam_repair_threads     = <%= node['mysql']['tunable']['myisam_repair_threads'] %>
myisam-recover            = <%= node['mysql']['tunable']['myisam-recover'] %>

#
# * NDB Cluster
#
# See /usr/share/doc/mysql-server-*/README.Debian for more information.
#
# The following configuration is read by the NDB Data Nodes (ndbd processes)
# not from the NDB Management Nodes (ndb_mgmd processes).
#
# [MYSQL_CLUSTER]
# ndb-connectstring=127.0.0.1

<% case node['platform_family'] -%>
<% when "rhel", "fedora", "suse" -%>
#
# * BerkeleyDB
#
# Using BerkeleyDB is now discouraged as its support will cease in 5.1.12.
skip-bdb
# Default to using old password format for compatibility with mysql 3.x
# clients (those using the mysqlclient10 compatibility package).
old_passwords           = <%= node['mysql']['old_passwords'] %>
<% end -%>

<% if node['mysql']['confd_dir'] -%>
#
# * IMPORTANT: Additional settings that can override those from this file!
#   The files must end with '.cnf', otherwise they'll be ignored.
#
!includedir <%= node['mysql']['confd_dir'] %>/
<% end -%>
