name             "dmg"
maintainer       "Joshua Timberman"
maintainer_email "cookbooks@housepub.org"
license          "Apache 2.0"
description      "LWRP to install OS X applications from dmgs"
long_description IO.read(File.join(File.dirname(__FILE__), 'README.md'))
version          "2.0.0"
supports         "mac_os_x"
