# Generated by Chef for <%= node['fqdn'] %>
# Local modifications will be overwritten.
[main]
cachedir=<%= node['yum']['cachedir'] %>/$basearch/$releasever
keepcache=<%= node['yum']['keepcache'] %>
debuglevel=2
logfile=/var/log/yum.log
exactarch=1
obsoletes=1
gpgcheck=1
plugins=1
installonly_limit=3
<%- unless node['yum']['exclude'].empty? %>
exclude=<%= node['yum']['exclude'].join(" ") %>
<%- end %>
<%- unless node['yum']['installonlypkgs'].empty? %>
installonlypkgs=<%= node['yum']['installonlypkgs'].join(" ") %>
<%- end %>
<%- unless node['yum']['proxy'].empty? %>
proxy=<%= node['yum']['proxy'] %>
proxy_username=<%= node['yum']['proxy_username'] %>
proxy_password=<%= node['yum']['proxy_password'] %>
<%- end %>

#  This is the default, if you make this bigger yum won't see if the metadata
# is newer on the remote and so you'll "gain" the bandwidth of not having to
# download the new metadata and "pay" for it by yum not having correct
# information.
#  It is esp. important, to have correct metadata, for distributions like
# Fedora which don't keep old packages around. If you don't like this checking
# interupting your command line usage, it's much better to have something
# manually check the metadata once an hour (yum-updatesd will do this).
# metadata_expire=90m

# PUT YOUR REPOS HERE OR IN separate files named file.repo
# in /etc/yum.repos.d
