<VirtualHost *:80>
  ServerName <%= @params[:server_name] %>
  ServerAlias <% @params[:server_aliases].each do |a| %><%= a %> <% end %>
  DocumentRoot <%= @params[:docroot] %>
  RewriteEngine On

  <Directory <%= @params[:docroot] %>>
    Options <%= [@params[:directory_options] || "FollowSymLinks" ].flatten.join " " %>
    AllowOverride <%= [@params[:allow_override] || "None" ].flatten.join " " %>
    Order allow,deny
    Allow from all
  </Directory>

  <Directory />
    Options FollowSymLinks
    AllowOverride None
  </Directory>

  <Location /server-status>
    SetHandler server-status

    Order Deny,Allow
    Deny from all
    Allow from 127.0.0.1
  </Location>

  LogLevel info
  ErrorLog <%= node['apache']['log_dir'] %>/<%= @params[:name] %>-error.log
  CustomLog <%= node['apache']['log_dir'] %>/<%= @params[:name] %>-access.log combined

  <% if @params[:directory_index] -%>
  DirectoryIndex <%= [@params[:directory_index]].flatten.join " " %>
  <% end -%>

  RewriteEngine On
  RewriteLog <%= node['apache']['log_dir'] %>/<%= @application_name %>-rewrite.log
  RewriteLogLevel 0

  # Canonical host, <%= @params[:server_name] %>
  RewriteCond %{HTTP_HOST}   !^<%= @params[:server_name] %> [NC]
  RewriteCond %{HTTP_HOST}   !^$
  RewriteRule ^/(.*)$        http://<%= @params[:server_name] %>/$1 [L,R=301]

  RewriteCond %{DOCUMENT_ROOT}/system/maintenance.html -f
  RewriteCond %{SCRIPT_FILENAME} !maintenance.html
  RewriteRule ^.*$ /system/maintenance.html [L]
</VirtualHost>
