# Generated by Chef for <%= node['fqdn'] %>
# Local modifications will be overwritten.
[main]
cachedir=<%= node['yum']['cachedir'] %>
keepcache=<%= node['yum']['keepcache'] %>
debuglevel=2
logfile=/var/log/yum.log
distroverpkg=redhat-release
tolerant=1
exactarch=1
obsoletes=1
gpgcheck=1
plugins=1
<%- unless node['yum']['exclude'].empty? %>
exclude=<%= node['yum']['exclude'].join(" ") %>
<%- end %>
<%- unless node['yum']['installonlypkgs'].empty? %>
installonlypkgs=<%= node['yum']['installonlypkgs'].join(" ") %>
<%- end %>
<%- unless node['yum']['proxy'].empty? %>
proxy=<%= node['yum']['proxy'] %>
proxy_username=<%= node['yum']['proxy_username'] %>
proxy_password=<%= node['yum']['proxy_password'] %>
<%- end %>

# Note: yum-RHN-plugin doesn't honor this.
metadata_expire=1h

# Default.
# installonly_limit = 3

# PUT YOUR REPOS HERE OR IN separate files named file.repo
# in /etc/yum.repos.d
