; configuration for php <%= @name %> module
<% @extensions.each do |filepath, zend| -%>
<%= 'zend_' if zend %>extension=<%= filepath %>
<% end -%>
<% @directives.each do |k,v| -%>
<%= "#{@name}.#{k}=\"#{v}\"" %>
<% end -%>
