# Generated by Chef for <%= node['fqdn'] %>
# Local modifications will be overwritten.
[<%= @repo_name %>]
name=<%= @description %>
<% if @type %>
type=<%= @type %>
<% end %>
<% unless @url.empty? -%>
baseurl=<%= @url %>
<% end -%>
<% if @mirrorlist %>
mirrorlist=<%= @mirrorlist %>
<% end %>
<% if @key %>
gpgcheck=1
gpgkey=file:///etc/pki/rpm-gpg/<%= @key %>
<% else %>
gpgcheck=0
<% end %>
enabled=<%= @enabled %>
<% if @failovermethod %>
failovermethod=<%= @failovermethod %>
<% end %>
<% if @bootstrapurl %>
bootstrapurl=<%= @bootstrapurl %>
<% end %>
<% if @includepkgs %>
includepkgs=<%= @includepkgs %>
<% end %>
<% if @exclude %>
exclude=<%= @exclude %>
<% end %>
<% if @priority %>
priority=<%= @priority %>
<% end %>
<% if @metadata_expire %>
metadata_expire=<%= @metadata_expire%>
<% end %>
<% if @type %>
type=<%= @type%>
<% end %>
