<IfModule mod_status.c>
#
# Allow server status reports generated by mod_status,
# with the URL of http://servername/server-status
# Uncomment and change the ".example.com" to allow
# access from other hosts.
#
<Location /server-status>
    SetHandler server-status
    Order deny,allow
    Deny from all
    Allow from <%=node['apache']['status_allow_list']%>
#    Allow from .example.com
</Location>
#
# ExtendedStatus controls whether Apache will generate "full" status
# information (ExtendedStatus On) or just basic information (ExtendedStatus
# Off) when the "server-status" handler is called. The default is Off.
#
<% if node['apache']['ext_status'] %>
ExtendedStatus On
<% else -%>
ExtendedStatus Off
<% end -%>
#
</IfModule>
