<IfModule mod_deflate.c>
          AddOutputFilterByType DEFLATE text/html
          AddOutputFilterByType DEFLATE text/css
          AddOutputFilterByType DEFLATE text/plain
          AddOutputFilterByType DEFLATE text/xml
          AddOutputFilterByType DEFLATE application/xhtml+xml
          AddOutputFilterByType DEFLATE application/xml
          AddOutputFilterByType DEFLATE image/svg+xml
          AddOutputFilterByType DEFLATE application/rss+xml
          AddOutputFilterByType DEFLATE application/atom_xml
          AddOutputFilterByType DEFLATE application/javascript
          AddOutputFilterByType DEFLATE application/x-javascript
          AddOutputFilterByType DEFLATE application/x-httpd-php
          AddOutputFilterByType DEFLATE application/x-httpd-fastphp
          AddOutputFilterByType DEFLATE application/x-httpd-eruby
</IfModule>
